@@ -21,9 +21,11 @@ int main(int argc, char *argv[])
     int i, size;
     char *xml;
     MCAgencyOptions_t options;
+    int port = 5051;
+    int remote_port = 5050;
 
     MC_InitializeAgencyOptions(&options);
-    MC_SetThreadOff(&options, MC_THREAD_CP);
+    MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
     if (argc == 2) {
         printf("Starting agency listening on port %d.\n",
                 atoi(argv[1]) );
@@ -33,7 +35,7 @@ int main(int argc, char *argv[])
                 );
     } else {
         agency = MC_Initialize(
-                5051,
+                port,
                 &options);
     }
  /* Note: The third argument of the following function may also be a
@@ -42,7 +44,7 @@ int main(int argc, char *argv[])
             agency,
             "agent.xml",
             "localhost",
-            5050 ); 
+            remote_port); 
     while(1) {
         printf("Waiting for agent return...\n");
         MC_WaitSignal(
@@ -63,11 +65,19 @@ int main(int argc, char *argv[])
             break;
         }
     }
+    /* Get and print the agent's XML code */
     xml = MC_GetAgentXMLString(agent);
     printf("%s\n", xml);
     free(xml);
+
+    /* Retrieve the agent's return data */
     MC_GetAgentReturnData(agent, 0, (void**)&array, &dim, &extent);
+
+    /* Since we have previously called MC_WaitSignal(), we must now reset 
+     * the signal to allow the agency to continue. */
     MC_ResetSignal(agency);
+
+    /* Print relevant data */
     printf("dim is %d\n", dim);
     printf("Extents are: ");
     size = 1;
