@@ -37,9 +37,9 @@ int main()
 {
     printf("Static int in library: %i\n", get_inc_int());
     printf("Setting call back pointer in library.\n");
-    setCallback(callback);
+    setFxCallback(callback);
     printf("Calling call back in library.\n");
-    callFptr(msg);
+    callFxCallback(msg);
     printf("Static int in library: %i\n", get_inc_int());
     
     return 0;
