@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 249 $ : Last Committed Revision
- * $Date: 2008-12-12 17:33:25 -0800 (Fri, 12 Dec 2008) $ : Last Committed Date */
+ * $Revision: 261 $ : Last Committed Revision
+ * $Date: 2009-01-09 16:32:51 -0800 (Fri, 09 Jan 2009) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -239,6 +239,13 @@ mc_platform_Destroy(mc_platform_p platform)
     message_queue_Destroy(platform->asm_message_queue);
   }
 #endif
+  /* Close the listen socket */
+#ifdef _WIN32
+  closesocket(platform->sockfd);
+#else
+  close(platform->sockfd);
+#endif
+
   message_queue_Destroy(platform->message_queue);
 
   agent_queue_Destroy(platform->agent_queue);
