@@ -1,24 +1,21 @@
-/* SVN FILE INFO
- * $Revision: 182 $ : Last Committed Revision
- * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
 /*
  *  sha2sum demonstration program
  *
  *  Copyright (C) 2006-2007  Christophe Devine
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License, version 2.1 as published by the Free Software Foundation.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA  02110-1301  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _CRT_SECURE_NO_DEPRECATE
@@ -30,7 +27,7 @@
 
 #include "xyssl/sha2.h"
 
-int sha2_wrapper( char *filename, unsigned char *sum )
+static int sha2_wrapper( char *filename, unsigned char *sum )
 {
     int ret = sha2_file( filename, sum, 0 );
 
@@ -43,7 +40,7 @@ int sha2_wrapper( char *filename, unsigned char *sum )
     return( ret );
 }
 
-int sha2_print( char *filename )
+static int sha2_print( char *filename )
 {
     int i;
     unsigned char sum[32];
@@ -58,7 +55,7 @@ int sha2_print( char *filename )
     return( 0 );
 }
 
-int sha2_check( char *filename )
+static int sha2_check( char *filename )
 {
     int i;
     size_t n;
